---
title: <span class="badge object-type-scalar"></span> MegahertzRotation
---
# <span class="badge object-type-scalar"></span> MegahertzRotation

Rotational Speed: Megahertz (MHz)

## Definition

```python
# Rotational Speed: Megahertz (MHz)
MegahertzRotation: typing.Literal["rotmhz"] = "rotmhz"
```
